% Programme : 
% calcul de la coalescence en tube  par turbulence
% permet la simulation de l'volution de d00, sigma et d32, connaissant jm,RG,
% pour une polydispersion
% Derniere mise a jour : mardi 31 octobre 2006

clear all;
close all;




	% 1- Constantes du modle et proprits du fluide
	
	Kc1 = 1;% constante du taux de collision pour la coalescence due  la turbulence
	Kp1 = 2;% constante de la probabilit de coalescence due  la turbulence
	D=0.04; %diamtre du tube

	% Proprits physique du liquide
	mu_l  = 1e-3;                % viscosit dynamique du liquide
	rho_l = 1e3;                 % densit du liquide
	nu_l  = mu_l/rho_l;          % viscosit cintique du liquide
	tension_de_surface = 7e-2;   % tension de surface
	% Autres constantes
	kappa = 0.41;                     % constante de von Karman 
	le = kappa * D/2;                 % chelle intgrale
		% Coefficient de masse virtuelle
	Cvm_d00 = 0.803;
	% Initialisation des variables max pour l'affichage des graphiques  la fin
	max_d32 = 0;
	max_d00 = 0;
	max_sigma =0;




   % 2 Lecture des donnees d'entree
    
    jm = 0.939;				% vitesse de melange
    RG = 0.0412;			% fraction moyenne du gaz moyenne
	d00e = 0.003067;			% diametre d00 en entree
	sighate=0.270;			% Ecart type en entree
	d00s = 0.006203;			% diametre d00 en sortie
	sighats=0.378;			% Ecart type en sortie
    L = 2.86;				% longueur du tube
    d32e = 0.00368;			% d32 en entree
    d32s = 0.00887;			% d32 en sortie
   
	
   % 3 Calcul des parametres de l'ecoulement	
	
   Re_melange = jm*D/nu_l;									% nombre  de Reynolds du mlange
	UG = 1.2*jm;												% vitesse moyenne du gaz (coef C0=1.2)
	ustar = jm*sqrt(0.5*0.079*Re_melange^(-0.25));	% vitesse turbulente de la phase liquide
	Epsilon = ustar^3/le;      							% dissipation rate of turb.kin. en.


	% 4 Initialisation des variables calcules
	
	Nombre_Iterations = 1000;
	pas = L/Nombre_Iterations;	% pas de calcul sur le diamtre de Sauter
	d0 = [];				% variable de stockage du diamtre mdian
    d32_stockage = [];% variable de stockage du diamtre de Sauter		
	sig = [];			% variable de stockage du paramtre sigma
    z = [];				% axes des abcisses du tube
	d00 = d00e;
	sighat=sighate;
	S1=6*RG/pi/d00^2*exp(-4*sighat^2);
    S2=6*RG/pi/d00*exp(-5/2*sighat^2);
    d32 = d32e;

   
 	 % 5 Calcul de l'volution de d00, sighat, d32 le long du tube
   	
	 for i=1:Nombre_Iterations,
		Beta = 0.6;
   		Ct = sqrt( (9+72*Beta*nu_l*le/d00^2/ustar) / (1+72*Beta*nu_l*le/d00^2/ustar) );
     	We00 = rho_l * ((Epsilon*d00)^(1/3)*Ct/sqrt(1.61))^2 * d00 / 2 / tension_de_surface;% 2-4-1-2 Weber du diametre median
 		 P00 = exp(-Kp1*sqrt(We00/Cvm_d00));% Cacul de P00 probabilt de colaescence pour le diamtre d00
     	 %  5-1 Calcul des fonctions f1 et f2
	  		g1=1-0.0531*sighat-0.6283*sighat^2;
	  		c1=1+0.0374*sighat+1.3936*sighat^2;
	  		g2=1-0.0411*sighat-0.2524*sighat^2;
	  		c2=1-0.0148*sighat+1.9383*sighat^2;
	  		f1 = g1*P00^c1;
			f2 = g2*P00^c2;
		
         %  5-2 Taux de coalescence par turbulence
      	dS1_dz = Kc1 * sqrt(8*pi/3) * (6*RG/pi)^(2/3) * Ct * Epsilon^(1/3) / sqrt(1.61) / UG * (2^(1/3)-2)...
 					* S1^(4/3) * f1;
      	dS2_dz = Kc1 * sqrt(8*pi/3) * (6*RG/pi)^(1/3) * Ct * Epsilon^(1/3) / sqrt(1.61) / UG * (2^(2/3)-2)...
         	* S2^(5/3) * f2;
           
     	 % 5-3 Calcul des nouveaux S1 et S2
      		S1=S1+dS1_dz*pas;
      		S2=S2+dS2_dz*pas;
      
     	 % 5-4 Calcul des nouveaux sighat d00 et d32 
  			 sighat=sqrt(log(6*RG*S1/pi/S2^2));
      		d00=6*RG/pi/S2*exp(-5/2*sighat^2);
     		 d32 = 6*RG/pi/S2;
      
      	% 5-5 Stokage des donnes
      		d0=	[d0 d00];
      		d32_stockage = [d32_stockage d32];
			sig=	[sig sighat];
     		z	=	[z i*pas];
		
	end;
  

   % 6 Traces des rsultats
   
   % 6-1 Traces des evolutions de d00 et de sighat
	figure;
   subplot(2,1,1);
   hold on;
   j=1;
   
   plot(z,d0,'')
   xlabel('z');
   ylabel('d_0_0');

   titre = strcat('Coalescence par turbulence en tube de 40mm');
	titre2 = strcat({titre, ' '}, {''}); 
   title(titre2);
   subplot(2,1,2);
   hold on;
   plot(z,sig,'')
   xlabel('z');
   ylabel('sigma');
 

	%Stockage dans une variable F des valeurs en entre et en sortie pour tous les essais
	F(j,1) = D;
	F(j,2) = L;
	F(j,3) = jm; %entree40(j,1);%jm
	F(j,4) =  RG; % entree40(j,2);%RG
	F(j,5) = d00e; %entree40(j,3);%d00e
	F(j,6) = sighate; % entree40(j,4);%sighate
	F(j,7) = d00s; %entree40(j,5);%d00s mesur
	F(j,8) = sighats; % entree40(j,6);%sighats mesur
	F(j,9) = d0(Nombre_Iterations);		%d00s calcul
    F(j,10) = sig(Nombre_Iterations);%sighats calcul
    F(j,11) = d32_stockage(Nombre_Iterations);	% d32 calcul en sortie
    F(j,12) = d32s;% d32 mesur en sortie
     


	% 6-2 Affichage des d00, sigma et d32 finaux en fin de tube
	
	% Affichage de d00 et d32
	figure;
	subplot(1,2,1); 
	hold on;
	xlissage=[0,1.2*d32s*1000];
   graph1 = plot (F(j,9)*1000,F(j,7)*1000,'r+',F(j,11)*1000,F(j,12)*1000,'bo',xlissage,xlissage,'k-');
   set(graph1,'LineWidth',2);set(graph1,'MarkerSize',4);
 	xlabel('calcul (mm)');
	ylabel('mesure (mm)');
	axis image;

	% Affichage Sigma 
	subplot(1,2,2); 
	hold on;
	xsig=[0,1.2*sighats]
    graph2 = plot (F(j,10),F(j,8),'+',xsig,xsig,'k-');
    set(graph2,'LineWidth',2);set(graph2,'MarkerSize',4);   
	xlabel('sigma calcul');
	ylabel('sigma mesur');
	axis image;


	%6-3 Affichage des pdf en fin de tube
	figure;
	% Pdf calcule en sortie
	Dmm=1000*D
    dd = 0.1;
    d = 0.1:dd:Dmm;
    d00s_calcule = 1000*F(j,9);
    sighats_calcul = F(j,10);
   pdf_calculee = 1 ./d /sighats_calcul /sqrt(2*pi) .*exp(-log(d./d00s_calcule).^2 / (2*sighats_calcul^2));
   max1 = max(pdf_calculee);
   hold on;
   graph51 = plot (d,pdf_calculee*dd,'b-');
   set(graph51,'LineWidth',1);set(graph51,'MarkerSize',1);
  
	% Pdf mesure en sortie
	d = 0.1:0.5:Dmm;
   d00s_mesure = 1000*F(j,7);
   sighats_mesure = F(j,8);
   pdf_mesuree = 1 ./d /sighats_mesure /sqrt(2*pi) .*exp(-log(d./d00s_mesure).^2 / (2*sighats_mesure^2));
   graph52 = plot (d,pdf_mesuree*dd,'r--');
   set(graph52,'LineWidth',2);set(graph52,'MarkerSize',2);
   max2 = max(pdf_mesuree);
   affichage = 1.05*max(max1,max2)/2*dd;
   xlabel('d (mm)');
   ylabel('P(d)');

